==> endpoints-1.0.0.tar.gz: endpoints-1.0.0/endpoints/interface/wsgi.py <==
from __future__ import absolute_import

from . import BaseInterface, BaseServer


class WSGI(BaseInterface):
    def create_request(self, raw_request, **kwargs):
        """
        create instance of request

        raw_request -- mongrel2.request.Request() -- the request object retrieved from mongrel2
        """
        r = self.request_class()
        for k, v in raw_request.iteritems():
            if k.startswith('HTTP_'):
                r.set_header(k[5:], v)
            else:
                r.environ[k] = v

        r.method = raw_request['REQUEST_METHOD']
        r.path = raw_request['PATH_INFO']
        r.query = raw_request['QUERY_STRING']
        r.raw_request = raw_request

        # handle headers not prefixed with http
        k = 'CONTENT_TYPE'
        ct = r.environ.pop(k, None)
        if ct:
            r.set_header(k, ct)

        if 'wsgi.input' in raw_request:
            body = raw_request['wsgi.input'].read()
            if not body: body = None
            r.body = body

        else:
            r.body = None

        return r


class Server(BaseServer):
    interface_class = WSGI

    def __call__(self, environ, start_response):
        return self.application(environ, start_response)

    def application(self, environ, start_response):
        res = self.interface.handle(environ)
        body = res.body # we do this to trigger the generator

        start_response(
            '{} {}'.format(res.code, res.status),
            [(k, str(v)) for k, v in res.headers.items()]
        )
        return [body]

    def create_server(self, **kwargs):
        return None

    def handle_request(self):
        raise NotImplemented("WSGI is handled through application() method")

    def serve_forever(self):
        raise NotImplemented("WSGI is handled through application() method")

    def serve_count(self, count):
        raise NotImplemented("WSGI is handled through application() method")

==> endpoints-1.0.12.tar.gz: endpoints-1.0.12/endpoints/interface/wsgi.py <==
from __future__ import absolute_import

from . import BaseInterface, BaseServer


class WSGI(BaseInterface):
    def create_request(self, raw_request, **kwargs):
        """
        create instance of request

        raw_request -- mongrel2.request.Request() -- the request object retrieved from mongrel2
        """
        r = self.request_class()
        for k, v in raw_request.iteritems():
            if k.startswith('HTTP_'):
                r.set_header(k[5:], v)
            else:
                r.environ[k] = v

        r.method = raw_request['REQUEST_METHOD']
        r.path = raw_request['PATH_INFO']
        r.query = raw_request['QUERY_STRING']
        r.raw_request = raw_request

        # handle headers not prefixed with http
        k = 'CONTENT_TYPE'
        ct = r.environ.pop(k, None)
        if ct:
            r.set_header(k, ct)

        if 'wsgi.input' in raw_request:
            r.body_input = raw_request['wsgi.input']
            #r.body_kwargs = self.normalize_body_kwargs(ct, raw_request['wsgi.input'], raw_request)

#             body = raw_request['wsgi.input'].read()
#             if not body: body = None
#             r.body = body

        else:
            r.body_kwargs = {}

        return r


class Server(BaseServer):
    interface_class = WSGI

    def __call__(self, environ, start_response):
        return self.application(environ, start_response)

    def application(self, environ, start_response):
        res = self.interface.handle(environ)
        body = res.body # we do this to trigger the generator

        start_response(
            '{} {}'.format(res.code, res.status),
            [(k, str(v)) for k, v in res.headers.items()]
        )
        return [body]

    def create_server(self, **kwargs):
        return None

    def handle_request(self):
        raise NotImplemented("WSGI is handled through application() method")

    def serve_forever(self):
        raise NotImplemented("WSGI is handled through application() method")

    def serve_count(self, count):
        raise NotImplemented("WSGI is handled through application() method")
